pub fn load() -> CableConfigExpand description
Load the current environment’s CableConfig, falling back to the default
(in-memory) when the file is missing or has no cable section.
pub fn load() -> CableConfigLoad the current environment’s CableConfig, falling back to the default
(in-memory) when the file is missing or has no cable section.