pub async fn ws_handler(
ws: WebSocketUpgrade,
__arg1: State<Arc<ChannelRegistry>>,
) -> ResponseExpand description
axum handler that upgrades a request to a cable WebSocket connection.
pub async fn ws_handler(
ws: WebSocketUpgrade,
__arg1: State<Arc<ChannelRegistry>>,
) -> Responseaxum handler that upgrades a request to a cable WebSocket connection.